Initable

Trait Initable 

pub trait Initable<'this>: Sized { }
Types that can be constructed using init_pin.

This trait is not meant for manual implementation and consumption. You should use #[pin_init] attribute to implement this trait, and init_pin! macro to use.

This trait is implemented on some std types so they can also be constructed using init_pin!.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<'this, T> Initable<'this> for Cell<T>

Source

impl<'this, T> Initable<'this> for UnsafeCell<T>

Source

impl<'this> Initable<'this> for PhantomPinned

Implementors